@@ -8,7 +8,7 @@
 #   The Artistic License 2.0 (GPL Compatible)
 #
 package Redis;
-$Redis::VERSION = '1.980';
+$Redis::VERSION = '1.981';
 # ABSTRACT: Perl binding for Redis database
 # VERSION
 # AUTHORITY
@@ -684,7 +684,8 @@ sub __send_command {
   my $cmd  = uc(shift);
   my $deb  = $self->{debug};
 
-  if ($self->{pid} != $$) {
+  # if already connected but after a fork, reconnect
+  if ($self->{sock} && ($self->{pid} // 0) != $$) {
     $self->connect;
   }
 
@@ -904,7 +905,7 @@ Redis - Perl binding for Redis database
 
 =head1 VERSION
 
-version 1.980
+version 1.981
 
 =head1 SYNOPSIS
 
